@@ -53,7 +53,7 @@ lsm_l_condent.RasterLayer <- function(landscape,
                      ordered = ordered,
                      base = base)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -74,7 +74,7 @@ lsm_l_condent.RasterStack <- function(landscape,
                      ordered = ordered,
                      base = base)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -95,7 +95,7 @@ lsm_l_condent.RasterBrick <- function(landscape,
                      ordered = ordered,
                      base = base)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -118,7 +118,7 @@ lsm_l_condent.stars <- function(landscape,
                      ordered = ordered,
                      base = base)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -139,7 +139,7 @@ lsm_l_condent.list <- function(landscape,
                      ordered = ordered,
                      base = base)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -154,14 +154,15 @@ lsm_l_condent_calc <- function(landscape, neighbourhood, ordered, base){
         landscape <- raster::as.matrix(landscape)
     }
 
-    cmh  <- rcpp_get_composition_vector(landscape)
+    com <- rcpp_get_coocurrence_matrix(landscape,
+                                       directions = as.matrix(neighbourhood))
+    com_c <- colSums(com)
 
     coh <- rcpp_get_coocurrence_vector(landscape,
                                        directions = as.matrix(neighbourhood),
                                        ordered = ordered)
 
-    comp <- rcpp_get_entropy(cmh, base)
-
+    comp <- rcpp_get_entropy(com_c, base)
     cplx <- rcpp_get_entropy(coh, base)
 
     conf <- cplx - comp
