@@ -1,8 +1,11 @@
 #' ENT (landscape level)
 #'
-#' @description Shannon entropy
+#' @description A metric of a compositional complexity of a pattern (a pattern
+#' diversity)
 #'
 #' @param landscape Raster* Layer, Stack, Brick or a list of rasterLayers.
+#' @param neighbourhood The number of directions in which cell adjacencies are considered as neighbours:
+#' 4 (rook's case) or 8 (queen's case). The default is 4.
 #' @param base The unit in which entropy is measured.
 #' The default is "log2", which compute entropy in "bits".
 #' "log" and "log10" can be also used.
@@ -28,17 +31,22 @@
 #' landscape complexity. https://doi.org/10.1101/383281
 #'
 #' @export
-lsm_l_ent <- function(landscape, base = "log2") UseMethod("lsm_l_ent")
+lsm_l_ent <- function(landscape,
+                      neighbourhood,
+                      base) UseMethod("lsm_l_ent")
 
 #' @name lsm_l_ent
 #' @export
-lsm_l_ent.RasterLayer <- function(landscape, base = "log2") {
+lsm_l_ent.RasterLayer <- function(landscape,
+                                  neighbourhood = 4,
+                                  base = "log2") {
 
     result <- lapply(X = raster::as.list(landscape),
                      FUN = lsm_l_ent_calc,
+                     neighbourhood = neighbourhood,
                      base = base)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -48,13 +56,16 @@ lsm_l_ent.RasterLayer <- function(landscape, base = "log2") {
 
 #' @name lsm_l_ent
 #' @export
-lsm_l_ent.RasterStack <- function(landscape, base = "log2") {
+lsm_l_ent.RasterStack <- function(landscape,
+                                  neighbourhood = 4,
+                                  base = "log2") {
 
     result <- lapply(X = raster::as.list(landscape),
                      FUN = lsm_l_ent_calc,
+                     neighbourhood = neighbourhood,
                      base = base)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -64,13 +75,16 @@ lsm_l_ent.RasterStack <- function(landscape, base = "log2") {
 
 #' @name lsm_l_ent
 #' @export
-lsm_l_ent.RasterBrick <- function(landscape, base = "log2") {
+lsm_l_ent.RasterBrick <- function(landscape,
+                                  neighbourhood = 4,
+                                  base = "log2") {
 
     result <- lapply(X = raster::as.list(landscape),
                      FUN = lsm_l_ent_calc,
+                     neighbourhood = neighbourhood,
                      base = base)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -80,15 +94,18 @@ lsm_l_ent.RasterBrick <- function(landscape, base = "log2") {
 
 #' @name lsm_l_ent
 #' @export
-lsm_l_ent.stars <- function(landscape, base = "log2") {
+lsm_l_ent.stars <- function(landscape,
+                            neighbourhood = 4,
+                            base = "log2") {
 
     landscape <- methods::as(landscape, "Raster")
 
     result <- lapply(X = raster::as.list(landscape),
                      FUN = lsm_l_ent_calc,
+                     neighbourhood = neighbourhood,
                      base = base)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -98,13 +115,16 @@ lsm_l_ent.stars <- function(landscape, base = "log2") {
 
 #' @name lsm_l_ent
 #' @export
-lsm_l_ent.list <- function(landscape, base = "log2") {
+lsm_l_ent.list <- function(landscape,
+                           neighbourhood = 4,
+                           base = "log2") {
 
     result <- lapply(X = landscape,
                      FUN = lsm_l_ent_calc,
+                     neighbourhood = neighbourhood,
                      base = base)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -112,16 +132,18 @@ lsm_l_ent.list <- function(landscape, base = "log2") {
     tibble::add_column(result, layer, .before = TRUE)
 }
 
-lsm_l_ent_calc <- function(landscape, base){
+lsm_l_ent_calc <- function(landscape, neighbourhood, base){
 
     # convert to matrix
     if(class(landscape) != "matrix") {
         landscape <- raster::as.matrix(landscape)
     }
 
-    cmh  <- rcpp_get_composition_vector(landscape)
+    com <- rcpp_get_coocurrence_matrix(landscape,
+                                       directions = as.matrix(neighbourhood))
+    com_c <- colSums(com)
 
-    comp <- rcpp_get_entropy(cmh, base)
+    comp <- rcpp_get_entropy(com_c, base)
 
     tibble::tibble(
         level = "landscape",
