@@ -56,7 +56,7 @@ lsm_p_para.RasterLayer <- function(landscape, directions = 8) {
                      FUN = lsm_p_para_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -72,7 +72,7 @@ lsm_p_para.RasterStack <- function(landscape, directions = 8) {
                      FUN = lsm_p_para_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -88,7 +88,7 @@ lsm_p_para.RasterBrick <- function(landscape, directions = 8) {
                      FUN = lsm_p_para_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -106,7 +106,7 @@ lsm_p_para.stars <- function(landscape, directions = 8) {
                      FUN = lsm_p_para_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
@@ -122,7 +122,7 @@ lsm_p_para.list <- function(landscape, directions = 8) {
                      FUN = lsm_p_para_calc,
                      directions = directions)
 
-    layer <- rep(seq_len(length(result)),
+    layer <- rep(seq_along(result),
                  vapply(result, nrow, FUN.VALUE = integer(1)))
 
     result <- do.call(rbind, result)
