@@ -3,6 +3,7 @@ context("class level lsm_c_pafrac metric")
 landscapemetrics_class_landscape_value <- lsm_c_pafrac(landscape)
 
 test_that("lsm_c_pafrac is typestable", {
+
     expect_is(lsm_c_pafrac(landscape), "tbl_df")
     expect_is(lsm_c_pafrac(landscape_stack), "tbl_df")
     expect_is(lsm_c_pafrac(landscape_brick), "tbl_df")
@@ -10,10 +11,12 @@ test_that("lsm_c_pafrac is typestable", {
 })
 
 test_that("lsm_c_pafrac returns the desired number of columns", {
+
     expect_equal(ncol(landscapemetrics_class_landscape_value), 6)
 })
 
 test_that("lsm_c_pafrac returns in every column the correct type", {
+
     expect_type(landscapemetrics_class_landscape_value$layer, "integer")
     expect_type(landscapemetrics_class_landscape_value$level, "character")
     expect_type(landscapemetrics_class_landscape_value$class, "integer")
@@ -23,6 +26,8 @@ test_that("lsm_c_pafrac returns in every column the correct type", {
 })
 
 test_that("lsm_c_pafrac throws error for less than 10 patches",  {
+
     expect_warning(lsm_c_pafrac(landscape_uniform),
-                   regexp = "Class 1: PAFRAC = NA for class with < 10 patches")
+                   grep = "Class 1: PAFRAC = NA for class with < 10 patches",
+                   fixed = TRUE)
 })
